@@ -15,7 +15,7 @@
 #   modify it under the same terms as Perl itself.
 #
 # REVISION
-#   $Id: Text.pm,v 1.2 2002/01/31 09:04:41 abw Exp $
+#   $Id: Text.pm 29 2009-03-17 07:46:38Z ford $
 #
 #========================================================================
 
@@ -29,7 +29,7 @@ use base qw( Pod::POM::View );
 use vars qw( $VERSION $DEBUG $ERROR $AUTOLOAD $INDENT );
 use Text::Wrap;
 
-$VERSION = sprintf("%d.%02d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
 $DEBUG   = 0 unless defined $DEBUG;
 $INDENT  = 0;
 
@@ -131,6 +131,18 @@ sub view_head4 {
 }
 
 
+#------------------------------------------------------------------------
+# view_over($self, $over)
+#
+# Present an =over block - this is a blockquote if there are no =items
+# within the block.
+#------------------------------------------------------------------------
+
+#sub view_over {
+#    my ($self, $over) = @_;
+#
+#}
+
 sub view_item {
     my ($self, $item) = @_;
     my $indent = ref $self ? \$self->{ INDENT } : \$INDENT;
@@ -199,6 +211,11 @@ sub view_seq_code {
 }
 
 
+sub view_seq_file {
+    my ($self, $text) = @_;
+    return "_${text}_";
+}
+
 my $entities = {
     gt   => '>',
     lt   => '<',
@@ -212,6 +229,10 @@ sub view_seq_entity {
     return $entities->{ $entity } || $entity;
 }
 
+sub view_seq_index {
+    return '';
+}
+
 sub view_seq_link {
     my ($self, $link) = @_;
     if ($link =~ s/^.*?\|//) {
